@@ -134,7 +134,7 @@
 #'
 #' \item{model}{ the fitting model (\code{=show.age-1}).}
 #'
-#' \item{x}{ a two element vector with the upper and lower intercept
+#' \item{x}{ a two-element vector with the upper and lower intercept
 #' ages (if \code{wetherill=TRUE}) or the lower intercept age and
 #' \eqn{^{207}}Pb/\eqn{^{206}}Pb intercept (if
 #' \code{wetherill=FALSE}).}
@@ -164,10 +164,12 @@
 #' w.r.t the analytical uncertainties (not reported if
 #' \code{show.age=3}).}
 #'
-#' \item{w}{ two-element vector with the standard deviation of the
-#' (assumedly) Normal overdispersion term and the corresponding
-#' \eqn{100(1-\alpha)\%} confidence interval (only important if
-#' \code{show.age=4}).}
+#' \item{w}{ three-element vector with the standard deviation of the
+#' (assumedly) Normal overdispersion term and the lower and upper
+#' half-widths of its \eqn{100(1-\alpha)\%} confidence interval (only
+#' important if \code{show.age=4}).}
+#'
+#' \item{n}{ the number of aliquots in the dataset }
 #'
 #' }
 #' @param ticks an optional vector of age ticks to be added to the
@@ -195,17 +197,19 @@ concordia <- function(x,tlim=NULL,alpha=0.05,wetherill=TRUE,
                       show.age=0,sigdig=2,common.Pb=0,ticks=NULL,...){
     if (common.Pb>0) X <- common.Pb.correction(x,option=common.Pb)
     else X <- x
-    concordia.line(X,tlim=tlim,wetherill=wetherill,col=concordia.col,
-                   alpha=alpha,exterr=exterr,ticks=ticks,...)
+    lims <- prepare.concordia.line(X,tlim=tlim,wetherill=wetherill,...)
     fit <- NULL
     if (show.age>1){
         fit <- concordia.intersection.ludwig(x,wetherill=wetherill,
                                              exterr=exterr,alpha=alpha,
                                              model=(show.age-1))
         discordia.line(fit,wetherill=wetherill)
+        fit$n <- length(x)
         graphics::title(discordia.title(fit,wetherill=wetherill,
                                         sigdig=sigdig))
     }
+    plot.concordia.line(X,lims=lims,wetherill=wetherill,col=concordia.col,
+                        alpha=alpha,exterr=exterr,ticks=ticks,...)
     ns <- length(x)
     ellipse.cols <- set.ellipse.colours(ns=ns,levels=levels,col=ellipse.col)
     for (i in 1:ns){
@@ -231,6 +235,7 @@ concordia <- function(x,tlim=NULL,alpha=0.05,wetherill=TRUE,
                              exterr=exterr,alpha=alpha)
         ell <- ellipse(fit$x[1],fit$x[2],fit$cov)
         graphics::polygon(ell,col='white')
+        fit$n <- length(x)
         graphics::title(concordia.title(fit,sigdig=sigdig))
     }
     colourbar(z=levels,col=ellipse.col,clabel=clabel)
@@ -238,17 +243,8 @@ concordia <- function(x,tlim=NULL,alpha=0.05,wetherill=TRUE,
 }
 
 # helper function for plot.concordia
-concordia.line <- function(x,tlim,wetherill,col,alpha=0.05,
-                           exterr=TRUE,ticks=NULL,...){
-    lims <- get.concordia.limits(x,tlim=tlim,wetherill=wetherill,...)
-    if (wetherill){
-        x.lab <- expression(paste(""^"207","Pb/"^"235","U"))
-        y.lab <- expression(paste(""^"206","Pb/"^"238","U"))
-    } else {
-        x.lab <- expression(paste(""^"238","U/"^"206","Pb"))
-        y.lab <- expression(paste(""^"207","Pb/"^"206","Pb"))
-    }
-    graphics::plot(lims$x,lims$y,type='n',xlab=x.lab,ylab=y.lab,...)
+plot.concordia.line <- function(x,lims,wetherill=TRUE,col='darksalmon',
+                                alpha=0.05,exterr=TRUE,ticks=NULL,...){
     range.t <- range(lims$t)
     m <- max(0.8*lims$t[1],lims$t[1]-range.t/20)
     M <- min(1.2*lims$t[2],lims$t[2]+range.t/20)
@@ -269,9 +265,8 @@ concordia.line <- function(x,tlim,wetherill,col,alpha=0.05,
         }
         concordia[i,] <- xy$x
     }
-    graphics::lines(concordia[,'x'],concordia[,'y'],col=col,lwd=2)
-    # prepare and plot ticks
     if (is.null(ticks)) ticks <- pretty(tt)
+    graphics::lines(concordia[,'x'],concordia[,'y'],col=col,lwd=2)
     for (i in 1:length(ticks)){
         xy <- age_to_concordia_ratios(ticks[i],wetherill=wetherill,exterr=exterr)
         if (exterr){ # show ticks as ellipse
@@ -285,6 +280,20 @@ concordia.line <- function(x,tlim,wetherill,col,alpha=0.05,
             (!wetherill & diff(range(concordia[,'x']))<2.5) & exterr){ pos <- NULL }
         graphics::text(xy$x[1],xy$x[2],as.character(ticks[i]),pos=pos)
     }
+    graphics::box()
+}
+# helper function for plot.concordia
+prepare.concordia.line <- function(x,tlim,wetherill=TRUE,...){
+    lims <- get.concordia.limits(x,tlim=tlim,wetherill=wetherill,...)
+    if (wetherill){
+        x.lab <- expression(paste(""^"207","Pb/"^"235","U"))
+        y.lab <- expression(paste(""^"206","Pb/"^"238","U"))
+    } else {
+        x.lab <- expression(paste(""^"238","U/"^"206","Pb"))
+        y.lab <- expression(paste(""^"207","Pb/"^"206","Pb"))
+    }
+    graphics::plot(lims$x,lims$y,type='n',xlab=x.lab,ylab=y.lab,bty='n')
+    lims
 }
 prettier <- function(x,wetherill=TRUE,n=20){
     m <- min(x)
@@ -388,10 +397,10 @@ get.concordia.limits <- function(x,tlim=NULL,wetherill=FALSE,...){
 # this would be much easier in unicode but that doesn't render in PDF:
 concordia.title <- function(fit,sigdig=2,alpha=0.05){
     rounded.age <- roundit(fit$age[1],fit$age[2:4],sigdig=sigdig)
-    expr1 <- expression('concordia age ='~a%+-%b~'|'~c)
-    list1 <- list(a=rounded.age[1],b=rounded.age[2],c=rounded.age[3])
+    expr1 <- expression('concordia age ='~a%+-%b~'|'~c~'Ma (n='~n~')')
+    list1 <- list(a=rounded.age[1],b=rounded.age[2],c=rounded.age[3],n=fit$n)
     if (fit$mswd['combined']>1){
-        expr1 <- expression('concordia age ='~a%+-%b~'|'~c~'|'~d)
+        expr1 <- expression('concordia age ='~a%+-%b~'|'~c~'|'~d~'Ma (n='~n~')')
         list1$d <- rounded.age[4]
     }
     line1 <- do.call('substitute',list(eval(expr1),list1))
@@ -460,13 +469,13 @@ concordia.age.wetherill <- function(x,t.init,exterr=TRUE,...){
 
 # x has class 'UPb'
 concordia.comp <- function(x,wetherill=TRUE){
-    if (wetherill) out <- wetherill(x,1)
-    else out <- tera.wasserburg(x,1)
-    fit.comp <- stats::optim(out$x[1:2], LL.concordia.comp,
-                             x=x,wetherill=wetherill,
-                             method="BFGS",hessian=TRUE)
-    out$x <- fit.comp$par
-    out$cov <- solve(fit.comp$hessian)
+    X <- flat.UPb.table(x,wetherill=wetherill)
+    out <- wtdmean2D(X)
+    cnames <- colnames(X)[c(1,3)]
+    names(out$x) <- cnames
+    colnames(out$cov) <- cnames
+    if (wetherill) class(out) <- 'wetherill'
+    else class(out) <- 'terawasserburg'
     out
 }
 
