@@ -4,6 +4,31 @@
 #' the Botev (2010) bandwidth selector and the Abramson (1982)
 #' adaptive kernel bandwidth modifier.
 #'
+#' @details
+#' Given a set of \eqn{n} age estimates \eqn{\{t_1, t_2, ..., t_n\}},
+#' histograms and KDEs are probability density estimators that display
+#' age distributions by smoothing.  Histograms do this by grouping the
+#' data into a number of regularly spaced bins.  Alternatively, kernel
+#' density estimates (KDEs; Vermeesch, 2012) smooth data by applying a
+#' (Gaussian) kernel:
+#'
+#' \eqn{KDE(t) = \sum_{i=1}^{n}N(t|\mu=t_i,\sigma=h[t])/n}
+#'
+#' where \eqn{N(t|\mu,\sigma)} is the probability of observing a
+#' value \eqn{t} under a Normal distribution with mean \eqn{\mu} and
+#' standard deviation \eqn{\sigma}.  \eqn{h[t]} is the smoothing
+#' parameter or `bandwidth' of the kernel density estimate, which may
+#' or may not depend on the age \eqn{t}. If \eqn{h[t]} depends on
+#' \eqn{t}, then \eqn{KDE(t)} is known as an `adaptive' KDE.  The
+#' default bandwidth used by \code{IsoplotR} is calculated using the
+#' algorithm of Botev et al. (2010) and modulated by the adaptive
+#' smoothing approach of Abramson (1982).  The rationale behind
+#' adaptive kernel density estimation is to use a narrower bandwidth
+#' near the peaks of the sampling distribution (where the ordered
+#' dates are closely spaced in time), and a wider bandwidth in the
+#' distribution's sparsely sampled troughs. Thus, the resolution of
+#' the density estimate is optimised according to data availability.
+#'
 #' @param x a vector of numbers OR an object of class \code{UPb},
 #'     \code{PbPb}, \code{ArAr}, \code{ReOs}, \code{SmNd},
 #'     \code{RbSr}, \code{UThHe}, \code{fissiontracks}, \code{ThU} or
@@ -11,16 +36,18 @@
 #' @rdname kde
 #' @export
 kde <- function(x,...){ UseMethod("kde",x) }
-#' @param from minimum age of the time axis. If \code{NULL}, this is set
-#'     automatically
+#' @param from minimum age of the time axis. If \code{NULL}, this is
+#'     set automatically
 #' @param to maximum age of the time axis. If \code{NULL}, this is set
 #'     automatically
-#' @param bw the bandwidth of the KDE. If \code{NULL}, \code{bw} will be calculated
-#'     automatically using \code{botev()}
+#' @param bw the bandwidth of the KDE. If \code{NULL}, \code{bw} will
+#'     be calculated automatically using the algorithm by Botev et
+#'     al. (2010).
 #' @param adaptive logical flag controlling if the adaptive KDE
 #'     modifier of Abramson (1982) is used
 #' @param log transform the ages to a log scale if \code{TRUE}
-#' @param n horizontal resolution of the density estimate
+#' @param n horizontal resolution (i.e., the number of segments) of
+#'     the density estimate.
 #' @param plot show the KDE as a plot
 #' @param pch the symbol used to show the samples. May be a vector.
 #'     Set \code{pch=NA} to turn them off.
@@ -31,30 +58,44 @@ kde <- function(x,...){ UseMethod("kde",x) }
 #' @param show.hist logical flag indicating whether a histogram should
 #'     be added to the KDE
 #' @param hist.col the fill colour of the histogram specified as a
-#'     four element vector of r, g, b, alpha values
+#'     four element vector of \code{r, g, b, alpha} values
 #' @param binwidth scalar width of the histogram bins, in Myr if
-#'     \code{x$log = FALSE}, or as a fractional value if
-#'     \code{x$log = TRUE}. Sturges' Rule is used if
-#'     \code{binwidth = NA}
+#'     \code{log = FALSE}, or as a fractional value if \code{log =
+#'     TRUE}. Sturges' Rule (\eqn{\log_2[n]+1}, where \eqn{n} is the
+#'     number of data points) is used if \code{binwidth = NA}
 #' @param bty change to \code{"o"}, \code{"l"}, \code{"7"},
 #'     \code{"c"}, \code{"u"}, or \code{"]"} if you want to draw a box
 #'     around the plot
 #' @param ncol scalar value indicating the number of columns over
-#'     which the KDEs should be divided. This option is only used if
-#'     \code{x} has class \code{detritals}.
-#' @param ... optional arguments to be passed on to \code{density}
+#'     which the KDEs should be divided.
+#' @param ... optional arguments to be passed on to \code{R}'s
+#'     \code{density} function.
+#' @seealso \code{\link{radialplot}}, \code{\link{cad}}
 #' @return
+#' If \code{x} has class \code{UPb}, \code{PbPb}, \code{ArAr},
+#' \code{ReOs}, \code{SmNd}, \code{RbSr}, \code{UThHe},
+#' \code{fissiontracks} or \code{ThU}, returns an object of class
+#' \code{KDE}, i.e. a list containing the following items:
 #'
-#' if \code{plot = TRUE}, returns an object of class \code{KDE}, i.e. a
-#'     list containing the following items:
-#' 
 #' \describe{
 #' \item{x}{ horizontal plot coordinates}
 #' \item{y}{ vertical plot coordinates}
 #' \item{bw}{ the base bandwidth of the density estimate}
-#' \item{ages}{ the data values from the input to the \code{kde} function}
+#' \item{ages}{ the data values from the input to
+#' the \code{kde} function}
+#' \item{log}{ copied from the input}
 #' }
 #'
+#' or, if \code{x} has class \code{=detritals}, an object of class
+#' \code{KDEs}, i.e. a list containing the following items:
+#'
+#' \describe{
+#' \item{kdes}{a named list with objects of class \code{KDE}}
+#' \item{from}{the beginning of the common time scale}
+#' \item{to}{the end of the common time scale}
+#' \item{themax}{the maximum probability density of all the KDEs}
+#' \item{xlabel}{the x-axis label to be used by \code{plot.KDEs(...)}}
+#' }
 #' @references
 #' Abramson, I.S., 1982. On bandwidth variation in kernel estimates-a
 #' square root law. The annals of Statistics, pp.1217-1223.
@@ -67,8 +108,13 @@ kde <- function(x,...){ UseMethod("kde",x) }
 #' distributions. Chemical Geology, 312, pp.190-194.
 #'
 #' @examples
-#' data(examples)
-#' kde(examples$DZ[['N1']],kernel="epanechnikov")
+#' kde(examples$UPb)
+#'
+#' dev.new()
+#' kde(examples$FT1,log=TRUE)
+#'
+#' dev.new()
+#' kde(examples$DZ,from=1,to=3000,kernel="epanechnikov")
 #' @importFrom grDevices rgb
 #' @rdname kde
 #' @export
@@ -76,15 +122,14 @@ kde.default <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                         n=512,plot=TRUE,pch=NA,xlab="age [Ma]",
                         ylab="",kde.col=rgb(1,0,1,0.6),
                         hist.col=rgb(0,1,0,0.2),show.hist=TRUE,
-                        bty='n',binwidth=NA,ncol=NA,...){
+                        bty='n',binwidth=NA,...){
     X <- getkde(x,from=from,to=to,bw=bw,adaptive=adaptive,log=log,n=n,...)
     if (plot) {
         plot.KDE(X,pch=pch,xlab=xlab,ylab=ylab,kde.col=kde.col,
                  hist.col=hist.col,show.hist=show.hist,bty=bty,
                  binwidth=binwidth)
-    } else {
-        return(X)
     }
+    invisible(X)
 }
 #' @param type scalar indicating whether to plot the
 #'     \eqn{^{207}}Pb/\eqn{^{235}}U age (\code{type}=1), the
@@ -97,13 +142,13 @@ kde.default <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
 #'     \eqn{^{206}}Pb/\eqn{^{238}}U and above which the
 #'     \eqn{^{207}}Pb/\eqn{^{206}}Pb age is used. This parameter is
 #'     only used if \code{type=4}.
-#' @param cutoff.disc two element vector with the maximum and minimum
-#'     percentage discordance allowed between the
-#'     \eqn{^{207}}Pb/\eqn{^{235}}U and \eqn{^{206}}Pb/\eqn{^{238}}U
-#'     age (if \eqn{^{206}}Pb/\eqn{^{238}}U < \code{cutoff.76}) or
-#'     between the \eqn{^{206}}Pb/\eqn{^{238}}U and
-#'     \eqn{^{207}}Pb/\eqn{^{206}}Pb age (if
-#'     \eqn{^{206}}Pb/\eqn{^{238}}U > \code{cutoff.76}).  Set
+#' @param cutoff.disc two element vector with the minimum (negative)
+#'     and maximum (positive) percentage discordance allowed between
+#'     the \eqn{^{207}}Pb/\eqn{^{235}}U and
+#'     \eqn{^{206}}Pb/\eqn{^{238}}U age (if
+#'     \eqn{^{206}}Pb/\eqn{^{238}}U < \code{cutoff.76}) or between the
+#'     \eqn{^{206}}Pb/\eqn{^{238}}U and \eqn{^{207}}Pb/\eqn{^{206}}Pb
+#'     age (if \eqn{^{206}}Pb/\eqn{^{238}}U > \code{cutoff.76}).  Set
 #'     \code{cutoff.disc=NA} if you do not want to use this filter.
 #' @param common.Pb apply a common lead correction using one of three
 #'     methods:
@@ -122,9 +167,9 @@ kde.default <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
 kde.UPb <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                     n=512,plot=TRUE,pch=NA,xlab="age [Ma]",ylab="",
                     kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
-                    show.hist=TRUE, bty='n',binwidth=NA,ncol=NA,
-                    type=4,cutoff.76=1100,cutoff.disc=c(-15,5),
-                    common.Pb=0,...){
+                    show.hist=TRUE, bty='n',binwidth=NA,type=4,
+                    cutoff.76=1100,cutoff.disc=c(-15,5),common.Pb=0,
+                    ...){
     if (common.Pb %in% c(1,2,3))
         X <- common.Pb.correction(x,option=common.Pb)
     else
@@ -133,8 +178,7 @@ kde.UPb <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
     kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
                 n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
                 kde.col=kde.col, hist.col=hist.col,
-                show.hist=show.hist,bty=bty,binwidth=binwidth,
-                ncol=ncol,...)
+                show.hist=show.hist,bty=bty,binwidth=binwidth,...)
 }
 #' @param samebandwidth logical flag indicating whether the same
 #'     bandwidth should be used for all samples. If
@@ -142,21 +186,6 @@ kde.UPb <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
 #'     function will use the median bandwidth of all the samples.
 #' @param normalise logical flag indicating whether or not the KDEs
 #'     should all integrate to the same value.
-#' @return
-#'
-#' or, if \code{x} has class \code{=detritals}, an object of class
-#' \code{KDEs}, i.e. a list containing the following items:
-#'
-#' \describe{
-#' \item{kdes}{a named list with objects of class \code{KDE}}
-#' \item{from}{the beginning of the common time scale}
-#' \item{to}{the end of the common time scale}
-#' \item{themax}{the maximum probability density of all the KDEs}
-#' \item{xlabel}{the x-axis label to be used by \code{plot.KDEs}}
-#' }
-#' 
-#' @examples
-#' kde(examples$DZ,from=0,to=3000)
 #' @rdname kde
 #' @export
 kde.detritals <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,
@@ -172,142 +201,130 @@ kde.detritals <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,
         plot.KDEs(X,pch=pch,xlab=xlab,ylab=ylab,kde.col=kde.col,
                   hist.col=hist.col,show.hist=show.hist,bty=bty,
                   binwidth=binwidth,ncol=ncol)
-    } else {
-        return(X)
     }
+    invisible(X)
 }
-#' @param i2i `isochron to intercept': calculates the initial
-#'     (aka `inherited', `excess', or `common') \eqn{^{40}}Ar/\eqn{^{36}}Ar,
-#'     \eqn{^{207}}Pb/\eqn{^{204}}Pb, \eqn{^{87}}Sr/\eqn{^{86}}Sr,
+#' @param i2i `isochron to intercept': calculates the initial (aka
+#'     `inherited', `excess', or `common')
+#'     \eqn{^{40}}Ar/\eqn{^{36}}Ar, \eqn{^{87}}Sr/\eqn{^{86}}Sr,
 #'     \eqn{^{143}}Nd/\eqn{^{144}}Nd, \eqn{^{187}}Os/\eqn{^{188}}Os or
 #'     \eqn{^{176}}Hf/\eqn{^{177}}Hf ratio from an isochron
 #'     fit. Setting \code{i2i} to \code{FALSE} uses the default values
-#'     stored in \code{settings('iratio',...)}  or zero (for the Pb-Pb
-#'     method). When applied to data of class \code{ThU}, setting
-#'     \code{i2i} to \code{TRUE} applies a detrital Th-correction.
+#'     stored in \code{settings('iratio',...)}. When applied to data
+#'     of class \code{ThU}, setting \code{i2i} to \code{TRUE} applies
+#'     a detrital Th-correction.
 #' @rdname kde
 #' @export
 kde.PbPb <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                      n=512,plot=TRUE,pch=NA,xlab="age [Ma]",ylab="",
                      kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
-                     show.hist=TRUE,bty='n',binwidth=NA,ncol=NA,
-                     i2i=FALSE,...){
-    tt <- PbPb.age(x,i2i=i2i)[,1]
+                     show.hist=TRUE,bty='n',binwidth=NA,common.Pb=1,
+                     ...){
+    if (common.Pb %in% c(1,2,3))
+        X <- common.Pb.correction(x,option=common.Pb)
+    else
+        X <- x
+    tt <- PbPb.age(X)[,1]
     kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
                 n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
                 kde.col=kde.col,hist.col=hist.col,
-                show.hist=show.hist,bty=bty,binwidth=binwidth,
-                ncol=ncol,...)
+                show.hist=show.hist,bty=bty,binwidth=binwidth,...)
 }
 #' @rdname kde
 #' @export
 kde.ArAr <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                      n=512,plot=TRUE,pch=NA,xlab="age [Ma]",ylab="",
                      kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
-                     show.hist=TRUE,bty='n',binwidth=NA,ncol=NA,
-                     i2i=FALSE,...){
+                     show.hist=TRUE,bty='n',binwidth=NA,i2i=FALSE,...){
     tt <- ArAr.age(x,i2i=i2i)[,1]
     kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
                 n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
                 kde.col=kde.col,hist.col=hist.col,
-                show.hist=show.hist,bty=bty,binwidth=binwidth,
-                ncol=ncol,...)
+                show.hist=show.hist,bty=bty,binwidth=binwidth,...)
 }
 #' @rdname kde
 #' @export
 kde.ThU <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                     n=512,plot=TRUE,pch=NA,xlab="age [ka]",ylab="",
                     kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
-                    show.hist=TRUE,bty='n',binwidth=NA,ncol=NA,
-                    i2i=FALSE,...){
+                    show.hist=TRUE,bty='n',binwidth=NA,i2i=FALSE,...){
     tt <- ThU.age(x,i2i=i2i)[,1]
     kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
                 n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
                 kde.col=kde.col,hist.col=hist.col,
-                show.hist=show.hist,bty=bty,binwidth=binwidth,
-                ncol=ncol,...)
+                show.hist=show.hist,bty=bty,binwidth=binwidth,...)
 }
 #' @rdname kde
 #' @export
 kde.ReOs <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                      n=512,plot=TRUE,pch=NA,xlab="age [Ma]",ylab="",
                      kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
-                     show.hist=TRUE,bty='n',binwidth=NA,ncol=NA,
-                     i2i=TRUE,...){
+                     show.hist=TRUE,bty='n',binwidth=NA,i2i=TRUE,...){
     tt <- ReOs.age(x,i2i=i2i)[,1]
     kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
                 n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
                 kde.col=kde.col,hist.col=hist.col,
-                show.hist=show.hist,bty=bty,binwidth=binwidth,
-                ncol=ncol,...)
+                show.hist=show.hist,bty=bty,binwidth=binwidth,...)
 }
 #' @rdname kde
 #' @export
 kde.SmNd <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                      n=512,plot=TRUE,pch=NA,xlab="age [Ma]",ylab="",
                      kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
-                     show.hist=TRUE,bty='n',binwidth=NA,ncol=NA,
-                     i2i=TRUE,...){
+                     show.hist=TRUE,bty='n',binwidth=NA,i2i=TRUE,...){
     tt <- SmNd.age(x,i2i=i2i)[,1]
     kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
                 n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
                 kde.col=kde.col,hist.col=hist.col,
-                show.hist=show.hist,bty=bty,binwidth=binwidth,
-                ncol=ncol,...)
+                show.hist=show.hist,bty=bty,binwidth=binwidth,...)
 }
 #' @rdname kde
 #' @export
 kde.RbSr <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                      n=512,plot=TRUE,pch=NA,xlab="age [Ma]",ylab="",
                      kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
-                     show.hist=TRUE,bty='n',binwidth=NA,ncol=NA,
-                     i2i=TRUE,...){
+                     show.hist=TRUE,bty='n',binwidth=NA,i2i=TRUE,...){
     tt <- RbSr.age(x,i2i=i2i)[,1]
     kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
                 n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
                 kde.col=kde.col,hist.col=hist.col,
-                show.hist=show.hist,bty=bty,binwidth=binwidth,
-                ncol=ncol,...)
+                show.hist=show.hist,bty=bty,binwidth=binwidth,...)
 }
 #' @rdname kde
 #' @export
 kde.LuHf <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                      n=512,plot=TRUE,pch=NA,xlab="age [Ma]",ylab="",
                      kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
-                     show.hist=TRUE,bty='n',binwidth=NA,ncol=NA,
-                     i2i=TRUE,...){
+                     show.hist=TRUE,bty='n',binwidth=NA,i2i=TRUE,...){
     tt <- LuHf.age(x,i2i=i2i)[,1]
     kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
                 n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
                 kde.col=kde.col,hist.col=hist.col,
-                show.hist=show.hist,bty=bty,binwidth=binwidth,
-                ncol=ncol,...)
+                show.hist=show.hist,bty=bty,binwidth=binwidth,...)
 }
 #' @rdname kde
 #' @export
 kde.UThHe <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                       n=512,plot=TRUE,pch=NA,xlab="age [Ma]",ylab="",
                       kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
-                      show.hist=TRUE,bty='n',binwidth=NA,ncol=NA,...){
+                      show.hist=TRUE,bty='n',binwidth=NA,...){
     tt <- UThHe.age(x)[,1]
     kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
                 n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
                 kde.col=kde.col, hist.col=hist.col,
-                show.hist=show.hist,bty=bty,binwidth=binwidth,
-                ncol=ncol,...)
+                show.hist=show.hist,bty=bty,binwidth=binwidth,...)
 }
 #' @rdname kde
 #' @export
 kde.fissiontracks <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                               n=512,plot=TRUE,pch=NA,xlab="age [Ma]",ylab="",
                               kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
-                              show.hist=TRUE,bty='n',binwidth=NA,ncol=NA,...){
+                              show.hist=TRUE,bty='n',binwidth=NA,...){
     tt <- fissiontrack.age(x)[,1]
     kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
                 n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
                 kde.col=kde.col, hist.col=hist.col,
-                show.hist=show.hist,bty=bty,binwidth=binwidth,
-                ncol=ncol,...)
+                show.hist=show.hist,bty=bty,binwidth=binwidth,...)
 }
 
 
